pub struct Capsule {
pub radius: f32,
pub half_length: f32,
}Expand description
A capsule shape aligned along the z-axis.
Mathematically, a capsule is the set of points that are at most radius units away from the line segment.
The line segment is defined by the two endpoints at (0, 0, -half_length) and (0, 0, half_length).
Fields
radius: f32The radius of the capsule.
half_length: f32The half length of the capsule along the z-axis.
Implementations