pub type InnerShapeWrapper = dyn Shape + Send + Sync;Expand description
A type alias for an object implementing the Shape trait. This is separated from ShapeWrapper to allow for implementing the Debug trait.
pub type InnerShapeWrapper = dyn Shape + Send + Sync;A type alias for an object implementing the Shape trait. This is separated from ShapeWrapper to allow for implementing the Debug trait.