pub type ShapeWrapper = Box<InnerShapeWrapper>;Expand description
A wrapper type for the Shape trait to allow dynamic dispatch.
Aliased Type
pub struct ShapeWrapper(/* private fields */);pub type ShapeWrapper = Box<InnerShapeWrapper>;A wrapper type for the Shape trait to allow dynamic dispatch.
pub struct ShapeWrapper(/* private fields */);