This module defines a trait for geometric shapes and a wrapper type for dynamic dispatch.
Enums
Traits
- Shape
- Shape trait for defining geometric shapes.
Type Aliases
- Inner
Shape Wrapper - A type alias for an object implementing the Shape trait. This is separated from ShapeWrapper to allow for implementing the Debug trait.
- Shape
Wrapper - A wrapper type for the Shape trait to allow dynamic dispatch.